@@ -1,34 +1,41 @@
 #!/usr/bin/env python3
 
+"""
+Method to work with the fasts journal.
+"""
+
+import typing
 from os.path import isfile
 
 from yaml import parser, safe_dump, safe_load
 
 
-def read_fasts() -> list:
+def read_fasts() -> list[dict[str, typing.Any]]:
+    """
+    Reads the fasts journal.
+    """
 
     yaml_file_name = __get_file_name()
 
     fasts = []
 
     if isfile(yaml_file_name):
-
         try:
-
             with open(yaml_file_name, encoding="utf-8-sig") as yaml_file:
                 fasts = safe_load(yaml_file)
 
         except parser.ParserError:
-
             print(f"Unable to parse: {yaml_file_name}")
 
     return fasts
 
 
-def write_fasts(fasts: list) -> None:
+def write_fasts(fasts: list[dict[str, typing.Any]]) -> None:
+    """
+    Writes the fasts journal.
+    """
 
     for fast in fasts:
-
         fast["started"] = fast["started"].replace(microsecond=0)
 
         if fast.get("stopped") is not None:
@@ -41,5 +48,4 @@ def write_fasts(fasts: list) -> None:
 
 
 def __get_file_name() -> str:
-
     return "fasts.yaml"
