@@ -1,21 +1,28 @@
 #!/usr/bin/env python3
 
-from vkostyanetsky import cliutils
+"""
+Generates the app's main menu.
+"""
+import datetime
+
+from vkostyanetsky import cliutils  # type: ignore
 
 from fastimer import view
 
 
-class FastimerMenu(cliutils.Menu):
-    _active_fast: dict | None = None
+class FastimerMenu(cliutils.Menu):  # type: ignore
+    """
+    This class represents main menu of the application.
+    """
 
-    def __init__(self, active_fast: dict | None = None):
+    _active_fast: dict[str, datetime.datetime | int] | None = None
 
+    def __init__(self, active_fast: dict[str, datetime.datetime | int] | None = None):
         super().__init__()
 
         self._active_fast = active_fast
 
-    def _print_menu(self):
-
+    def _print_menu(self) -> None:
         print(self._top_border())
 
         self._print_title()
@@ -26,14 +33,12 @@ class FastimerMenu(cliutils.Menu):
 
         print(self._bottom_border())
 
-    def _print_title(self):
-
+    def _print_title(self) -> None:
         print(self._text_line("FASTING TIMER", 2))
 
         print(self._inner_border())
 
-    def _print_choices(self):
-
+    def _print_choices(self) -> None:
         print(self._empty_line())
 
         for choice in self._get_choices_to_print():
@@ -41,10 +46,8 @@ class FastimerMenu(cliutils.Menu):
 
         print(self._empty_line())
 
-    def _print_active_fast(self):
-
+    def _print_active_fast(self) -> None:
         if self._active_fast is not None:
-
             active_fast_preview = view.get(self._active_fast)
 
             print(self._empty_line())
@@ -56,7 +59,7 @@ class FastimerMenu(cliutils.Menu):
 
             print(self._inner_border())
 
-    def print(self):
+    def print(self) -> None:
         """
         Draws the menu.
         """
